nbxmpp.protocol.ErrorNode

Package nbxmpp :: Module protocol :: Class ErrorNode |
[hide private]
[frames] | no frames]

# Class ErrorNode

source code

XMPP-style error element

In the case of stanza error should be attached to XMPP stanza. In the case of stream-level errors should be used separately.

Instance Methods | [hide private]
__init__(self, name, code=None, typ=None, text=None) Mandatory parameter: name - name of error condition. Optional parameters: code, typ, text. Used for backwards compartibility with older jabber protocol. | source code
Inherited from `simplexml.Node`: `__contains__`, `__delitem__`, `__getattr__`, `__getitem__`, `__setitem__`, `__str__`, `addChild`, `addData`, `clearData`, `delAttr`, `delChild`, `getAttr`, `getAttrs`, `getChildren`, `getData`, `getName`, `getNamespace`, `getParent`, `getPayload`, `getTag`, `getTagAttr`, `getTagData`, `getTags`, `has_attr`, `iterTags`, `lookup_nsp`, `setAttr`, `setData`, `setName`, `setNamespace`, `setParent`, `setPayload`, `setTag`, `setTagAttr`, `setTagData` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `simplexml.Node`: `FORCE_NODE_RECREATION`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, name, code=None, typ=None, text=None) (Constructor) | source code
Mandatory parameter: name - name of error condition. Optional parameters: code, typ, text. Used for backwards compartibility with older jabber protocol. Overrides: object.__init__